Client

Struct Client 

pub struct Client { /* private fields */ }
MCP client session

Implementations

Source

impl Client

pub fn new( transport: Box<dyn Transport + Send + Sync>, options: ClientOptions, ) -> (Self, Receiver<ClientEvent>)

Create a new client with the given transport and options

pub fn id(&self) -> &str

Get the client ID

pub async fn connect(&self) -> Result<(), Error>

Connect to the server

pub async fn disconnect(&self) -> Result<(), Error>

Disconnect from the server

pub async fn send_request( &self, request: JSONRPCRequest, ) -> Result<JSONRPCMessage, Error>

Send a request to the server and wait for a response

pub async fn send_notification( &self, notification: JSONRPCNotification, ) -> Result<(), Error>

Send a notification to the server

pub async fn list_resources(&self) -> Result<Vec<Resource>, Error>

List available resources

pub async fn list_resource_templates( &self, ) -> Result<Vec<ResourceTemplate>, Error>

List available resource templates

pub async fn read_resource( &self, uri: &str, ) -> Result<Vec<ResourceContent>, Error>

Read a resource

pub async fn subscribe_resource(&self, uri: &str) -> Result<(), Error>

Subscribe to resource updates

pub async fn unsubscribe_resource(&self, uri: &str) -> Result<(), Error>

Unsubscribe from resource updates

pub async fn list_prompts(&self) -> Result<Vec<Prompt>, Error>

List available prompts

pub async fn get_prompt( &self, name: &str, arguments: Option<HashMap<String, String>>, ) -> Result<Vec<PromptMessage>, Error>

Get a prompt

pub async fn list_tools(&self) -> Result<Vec<Tool>, Error>

List available tools

pub async fn call_tool( &self, name: &str, arguments: Option<Value>, ) -> Result<CallToolResult, Error>

Call a tool

pub async fn set_logging_level(&self, level: LoggingLevel) -> Result<(), Error>

Set the logging level

pub async fn get_completions( &self, reference_type: CompletionReferenceType, reference_name: &str, argument_name: &str, argument_value: &str, ) -> Result<CompleteResult, Error>

Get completions for an argument

pub async fn list_roots(&self) -> Result<Vec<Root>, Error>

List available roots (from server to client)

pub async fn notify_roots_changed(&self) -> Result<(), Error>

Notify the server that the roots list has changed

pub async fn ping(&self) -> Result<(), Error>

Ping the server

pub async fn cancel_request( &self, request_id: RequestId, reason: Option<String>, ) -> Result<(), Error>

Cancel a request