pub struct Resource {
pub uri: String,
pub name: String,
pub description: Option<String>,
pub mime_type: Option<String>,
pub annotations: Option<Annotations>,
pub size: Option<i64>,
}Expand description
A known resource that the server is capable of reading.
Fields
uri: StringThe URI of this resource.
name: StringA human-readable name for this resource.
description: Option<String>A description of what this resource represents.
mime_type: Option<String>The MIME type of this resource, if known.
annotations: Option<Annotations>Optional annotations for the client.
size: Option<i64>The size of the raw resource content in bytes, if known.
Implementations
Sourceimpl Resource
impl Resource
Sourcepub fn with_description(
uri: impl Into<String>,
name: impl Into<String>,
description: impl Into<String>,
) -> Self
pub fn with_description( uri: impl Into<String>, name: impl Into<String>, description: impl Into<String>, ) -> Self
Create a new resource with description
Sourcepub fn with_mime_type(self, mime_type: impl Into<String>) -> Self
pub fn with_mime_type(self, mime_type: impl Into<String>) -> Self
Set the MIME type for the resource
Sourcepub fn with_annotations(self, annotations: Annotations) -> Self
pub fn with_annotations(self, annotations: Annotations) -> Self
Set the annotations for the resource