RootsListChangedNotification

Struct RootsListChangedNotification 

pub struct RootsListChangedNotification {
    pub method: String,
    pub params: Option<Value>,
}
A notification from the client to the server, informing it that the list of roots has changed. This notification should be sent whenever the client adds, removes, or modifies any root. The server should then request an updated list of roots using the ListRootsRequest.

Fields

method: String

The method name

params: Option<Value>

The notification parameters

Implementations

Source

impl RootsListChangedNotification

pub fn new() -> Self

Create a new roots list changed notification